@@ -13,6 +13,8 @@ use super::beach_line as VB;
 use super::extended_exp_fpt as EX;
 
 use super::OutputType;
+#[cfg(feature = "console_debug")]
+use crate::tln;
 use crate::BvError;
 use ordered_float::OrderedFloat;
 use std::cell::Cell;
@@ -93,7 +95,7 @@ impl Default for CircleEvent {
 
 impl PartialEq for CircleEvent {
     fn eq(&self, other: &Self) -> bool {
-        //println!("eq self.idx:{:?}, other.idx:{:?}", self.index_, other.index_);
+        //tln!("eq self.idx:{:?}, other.idx:{:?}", self.index_, other.index_);
         self.center_x_ == other.center_x_
             && self.center_y_ == other.center_y_
             && self.lower_x_ == other.lower_x_
@@ -123,9 +125,9 @@ impl Ord for CircleEvent {
         } else if self.y() < other.y() {
             Ordering::Less
         } else if self.y() == other.y() {
-            //println!("cmp self.lx():{:.12}, other.lx:{:.12} si:{:?}", self.lower_x(), other.lower_x(), self._index);
-            //println!("cmp self.y():{:.12}, other.y:{:.12} oi:{:?}", self.y(), other.y(), self._index);
-            //println!("cmp self.idx:{:?}, other.idx:{:?}", self.index_, other.index_);
+            //tln!("cmp self.lx():{:.12}, other.lx:{:.12} si:{:?}", self.lower_x(), other.lower_x(), self._index);
+            //tln!("cmp self.y():{:.12}, other.y:{:.12} oi:{:?}", self.y(), other.y(), self._index);
+            //tln!("cmp self.idx:{:?}, other.idx:{:?}", self.index_, other.index_);
             if let Some(self_index) = self.index_ {
                 if let Some(other_index) = other.index_ {
                     self_index.0.cmp(&other_index.0)
@@ -219,9 +221,9 @@ impl PartialOrd for CircleEventC {
 
 impl Ord for CircleEventC {
     fn cmp(&self, other: &Self) -> Ordering {
-        let cself = self.0.get();
-        let cother = other.0.get();
-        cself.cmp(&cother)
+        let cell_self = self.0.get();
+        let cell_other = other.0.get();
+        cell_self.cmp(&cell_other)
     }
 }
 
@@ -351,6 +353,12 @@ where
     pub(crate) fn is_site_point(&self) -> bool {
         self.is_site_point_
     }
+
+    #[cfg(any(feature = "ce_corruption_check", feature = "console_debug"))]
+    #[allow(dead_code)]
+    pub fn dbg(&self) {
+        println!("[{},{}]", self.x().0, self.y().0);
+    }
 }
 
 pub type CircleEventType = Rc<CircleEventC>;
@@ -399,10 +407,26 @@ impl CircleEventQueue {
     #[cfg(not(feature = "map_first_last"))]
     #[inline]
     pub(crate) fn peek(&self) -> Option<&CircleEventType> {
-        // super inefficient implementation of 'first()'
+        // super inefficient implementation of 'first()' for +stable
         self.c_.iter().next()
     }
 
+    #[cfg(feature = "ce_corruption_check")]
+    pub(crate) fn ce_corruption_check(&self) {
+        if self.c_.len() >= 2 {
+            let mut iter = self.c_.iter();
+            let first_ce = iter.next().unwrap().0.get();
+            let second_ce = iter.next().unwrap().0.get();
+
+            if first_ce.cmp(&second_ce) != Ordering::Less {
+                println!("*************************************************");
+                println!("topmost CE could just as well been the second CE.");
+                println!("topmost CE :{:?}", first_ce);
+                println!("second CE :{:?}", second_ce);
+            }
+        }
+    }
+
     /// the real pop_firs() for +nightly builds
     #[inline(always)]
     #[cfg(feature = "map_first_last")]
@@ -412,7 +436,7 @@ impl CircleEventQueue {
 
     /// simulated pop_firs() for +stable builds
     #[cfg(not(feature = "map_first_last"))]
-    #[inline]
+    #[inline(always)]
     fn pop_first(&mut self) -> Option<CircleEventType> {
         if let Some(item) = self.c_.iter().next().cloned() {
             #[cfg(feature = "console_debug")]
@@ -426,8 +450,6 @@ impl CircleEventQueue {
     }
 
     pub(crate) fn pop_inactive_at_top(&mut self) -> Result<(), BvError> {
-        //let size_b4 = self.c_.len();
-
         while !self.is_empty() {
             if let Some(peek) = self.peek() {
                 if let Some(peek) = peek.0.get().get_index() {
@@ -512,6 +534,7 @@ impl CircleEventQueue {
         cc
     }
 
+    #[inline(always)]
     pub(crate) fn is_active(&self, circle_event_id: CircleEventIndex) -> bool {
         !self.inactive_circle_ids_.bit(circle_event_id.0)
     }
@@ -525,9 +548,9 @@ impl CircleEventQueue {
         if let Some(circle_event_id) = circle_event_id {
             if !self.inactive_circle_ids_.bit(circle_event_id.0) {
                 if self.c_list_.contains_key(&circle_event_id.0) {
-                    println!("deactivate {:?}", self.c_list_[&circle_event_id.0]);
+                    tln!("deactivate {:?}", self.c_list_[&circle_event_id.0]);
                 } else {
-                    println!("circle {} not present", circle_event_id);
+                    tln!("circle {} not present", circle_event_id);
                 }
                 let _ = self.inactive_circle_ids_.set_bit(circle_event_id.0, true);
             }
@@ -561,7 +584,7 @@ impl CircleEventQueue {
 
     /// Returns the number of circle events (both active and inactive)
     /// Only used by test code.
-    #[allow(dead_code)]
+    #[cfg(any(feature = "test", feature = "console_debug"))]
     pub(crate) fn len(&self) -> usize {
         self.c_.len()
     }
