@@ -415,8 +415,8 @@ where
     F: OutputType + Neg<Output = F>,
 {
     pub fn new(source_aabb: &Aabb2<I, F>, dest_aabb: &Aabb2<I, F>) -> Result<Self, BvError> {
-        let i32_to_f1 = super::TypeConverter2::<I, F>::i32_to_f;
-        let min_dim = i32_to_f1(10);
+        let i32_to_f = super::TypeConverter2::<I, F>::i32_to_f;
+        let min_dim = i32_to_f(10);
 
         if let Some(s_low) = source_aabb.get_low() {
             if let Some(s_high) = source_aabb.get_high() {
@@ -425,8 +425,8 @@ where
                         //println!("s_low:{:?},s_high:{:?},d_low:{:?},d_high:{:?}", s_low, s_high, d_low, d_high);
 
                         let source_aabb_center = [
-                            -(s_low[0] + s_high[0]) / i32_to_f1(2_i32),
-                            -(s_low[1] + s_high[1]) / i32_to_f1(2_i32),
+                            -(s_low[0] + s_high[0]) / i32_to_f(2_i32),
+                            -(s_low[1] + s_high[1]) / i32_to_f(2_i32),
                         ];
                         let source_aabb_size = [
                             (s_high[0] - s_low[0]).max(min_dim),
@@ -542,29 +542,23 @@ where
             + self.to_offset[1]
     }
 
-    /// transform from source coordinate system to dest coordinate system
+    /// transform from source coordinate system to destination coordinate system
     /// float x coordinate
     #[inline(always)]
     pub fn transform_fx(&self, x: F) -> F {
         (x + self.to_center_[0]) * self.scale[0] + self.to_offset[0]
     }
 
-    /// transform from source coordinate system to dest coordinate system
+    /// transform from source coordinate system to destination coordinate system
     /// float y coordinate
     #[inline(always)]
     pub fn transform_fy(&self, y: F) -> F {
         (y + self.to_center_[1]) * self.scale[1] + self.to_offset[1]
     }
 
-    /// Only scale
+    /// multiply the scale by a factor f
     #[inline(always)]
-    pub fn scale(&self, r: F) -> F {
-        r * self.scale[1]
-    }
-
-    /// Only scale
-    #[inline(always)]
-    pub fn reverse_scale(&self, r: F) -> F {
-        r / self.scale[1]
+    pub fn zoom(&mut self, f: F) {
+        self.scale = [self.scale[0] * f, self.scale[1] * f];
     }
 }
